@@ -1133,8 +1133,9 @@ ags_notation_is_note_selected(AgsNotation *notation, AgsNote *note)
   selection = notation->selection;
 
   while(selection != NULL && AGS_NOTE(selection->data)->x[0] <= note->x[0]){
-    if(selection->data == note)
+    if(selection->data == note){
       return(TRUE);
+    }
 
     selection = selection->next;
   }
@@ -1406,6 +1407,7 @@ ags_notation_add_region_to_selection(AgsNotation *notation,
 				     gboolean replace_current_selection)
 {
   AgsNote *note;
+
   GList *region, *list;
 
   region = ags_notation_find_region(notation,
@@ -1445,7 +1447,6 @@ ags_notation_add_region_to_selection(AgsNotation *notation,
   }
 }
 
-
 /**
  * ags_notation_remove_region_from_selection:
  * @notation: an #AgsNotation
@@ -1464,6 +1465,7 @@ ags_notation_remove_region_from_selection(AgsNotation *notation,
 					  guint x1, guint y1)
 {
   AgsNote *note;
+  
   GList *region;
 
   region = ags_notation_find_region(notation,
@@ -1498,8 +1500,10 @@ xmlNode*
 ags_notation_copy_selection(AgsNotation *notation)
 {
   AgsNote *note;
+
   xmlNode *notation_node, *current_note;
   xmlNode *timestamp_node;
+
   GList *selection;
 
   guint x_boundary, y_boundary;
@@ -1634,8 +1638,8 @@ ags_notation_cut_selection(AgsNotation *notation)
  * @x_offset: region start cursor offset
  * @reset_y_offset: if %TRUE @y_offset used as cursor
  * @y_offset: region start cursor tone
- * @match_channel: 
- * @no_duplicates: 
+ * @match_channel: only paste if channel matches
+ * @no_duplicates: only paste if current note doesn't exist
  *
  * Paste previously copied notes. 
  *
@@ -1954,6 +1958,21 @@ ags_notation_insert_from_clipboard(AgsNotation *notation,
 					      FALSE, FALSE);
 }
 
+/**
+ * ags_notation_insert_from_clipboard_extended:
+ * @notation: an #AgsNotation
+ * @notation_node: the clipboard XML data
+ * @reset_x_offset: if %TRUE @x_offset used as cursor
+ * @x_offset: region start cursor offset
+ * @reset_y_offset: if %TRUE @y_offset used as cursor
+ * @y_offset: region start cursor tone
+ * @match_channel: only paste if channel matches
+ * @no_duplicates: only paste if current note doesn't exist
+ * 
+ * Paste previously copied notes. 
+ * 
+ * Since: 1.3.0
+ */
 void
 ags_notation_insert_from_clipboard_extended(AgsNotation *notation,
 					    xmlNode *notation_node,
