@@ -423,9 +423,10 @@ ags_config_real_load_defaults(AgsConfig *config)
   ags_config_set_value(config, AGS_CONFIG_GENERIC, "engine-mode", "performance");
 
   ags_config_set_value(config, AGS_CONFIG_THREAD, "model", "super-threaded");
-  ags_config_set_value(config, AGS_CONFIG_THREAD, "super-threaded-scope", "channel");
+  ags_config_set_value(config, AGS_CONFIG_THREAD, "super-threaded-scope", "audio");
   ags_config_set_value(config, AGS_CONFIG_THREAD, "lock-global", "ags-thread");
   ags_config_set_value(config, AGS_CONFIG_THREAD, "lock-parent", "ags-recycling-thread");
+  ags_config_set_value(config, AGS_CONFIG_THREAD, "max-precision", "125");
 
 #ifdef AGS_WITH_CORE_AUDIO
   ags_config_set_value(config, AGS_CONFIG_SOUNDCARD_0, "backend", "core-audio");
